# Parking Utils Library

A utility library for parking applications with AWS integration.

## Installation
```bash

## python version required 3.9

## extract the zip folder and open any code editor

python3 -m venv venv

source venv/bin/activate

pip install -r requiremeents.txt

pip install -i https://test.pypi.org/simple/ parking-utils-aec

run the server